@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: gs_osishtmlhref.h,v 1.3 2004/09/26 18:25:39 tbiggs Exp $
+ * $Id: gs_osishtmlhref.h 1211 2006-04-10 15:15:04Z tbiggs $
  *
  * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -35,6 +35,8 @@ protected:
 		bool osisQToTick;
 		bool inBold;
 		bool inRed;
+		bool inName;
+		bool inNote;
 		SWBuf lastTransChange;
 		SWBuf w;
 		SWBuf fn;
