@@ -170,6 +170,11 @@ void BackEnd::init_SWORD(int gsType) {
 				display_mod->setDisplay(entryDisplay);
 			}
 		}	
+	} else if(gsType == 2) {	
+		for (it = display_mgr->Modules.begin(); it != display_mgr->Modules.end(); it++) {	
+			display_mod = (*it).second;
+			display_mod->setDisplay(entryDisplay);
+		}	
 	}
 }
 
@@ -483,8 +488,16 @@ char *BackEnd::get_valid_key(const char *key) {
 	vkey.AutoNormalize(1);
 	vkey = mykey;       
 	g_free(mykey);
-	
-	mykey = g_convert((char*)vkey.getShortText(),
+	if((sword_locale) && (!strcmp(sword_locale,"en")))
+		mykey = g_convert((char*)vkey.getShortText(),
+                             -1,
+                             UTF_8,
+                             OLD_CODESET,
+                             &bytes_read,
+                             &bytes_written,
+                             error);
+	else
+		mykey = g_convert((char*)vkey.getText(),
                              -1,
                              UTF_8,
                              OLD_CODESET,
@@ -698,21 +711,34 @@ int BackEnd::module_type(const char *mod_name) {
 
 char *BackEnd::module_description(char *mod_name) {
 	ModMap::iterator it;	//-- iteratior
+	char *description = NULL;                                                   
+        gsize bytes_read;
+        gsize bytes_written;
+        GError **error = NULL;
+	
 	if((!mod_name) || (strlen(mod_name) < 2)) 
 		return NULL;
 	//-- iterate through the modules until we find modName 
 	it = main_mgr->Modules.find(mod_name);
 	//-- if we find the module
-	if (it != main_mgr->Modules.end()) {
-		return (*it).second->Description();
+	if (it != main_mgr->Modules.end()) {	
+		description = g_convert((char*)(*it).second->Description(),
+                             -1,
+                             UTF_8,
+                             OLD_CODESET,
+                             &bytes_read,
+                             &bytes_written,
+                             error);
+		//g_message((*it).second->Description());
+		return description;  //(*it).second->Description();
 	}
 	return NULL;
 }
-
+ 
 char *BackEnd::module_name_from_description(char *description) {
 	ModMap::iterator it;
 	char *retval = NULL;
-	
+	 
 	if(!description)
 		return NULL;
 	
@@ -829,7 +855,7 @@ char *BackEnd::get_entry_attribute(const char *level1, const char *level2, const
 	return NULL;	
 }
 
-
+ 
 int BackEnd::set_module(const char *module_name) {
 	display_mod = display_mgr->Modules[module_name];
 	if (display_mod) 
@@ -945,6 +971,41 @@ void BackEnd::set_treekey(unsigned long offset) {
         }
 }
 
+unsigned long BackEnd::get_treekey_offset_from_key(const char * module_name, const char * key) {
+        SWModule *mod;
+	ModMap::iterator it;	//-- iteratior
+	char *mykey;                                                 
+        gsize bytes_read;
+       	gsize bytes_written;
+        GError *error = NULL;
+	unsigned long retval = 0;
+	//-- iterate through the modules until we find modName  
+	it = main_mgr->Modules.find(module_name);
+	//-- if we find the module
+	if (it != main_mgr->Modules.end()) {		
+		mod = (*it).second;
+		mykey = g_convert(key,
+                             -1,
+                             OLD_CODESET,
+                             UTF_8,
+                             &bytes_read,
+                             &bytes_written,
+                             &error);
+		if(error) {
+			g_print ("error: %s\n", error->message);
+			g_error_free (error);	
+		}		
+		TreeKeyIdx *tree_key_idx = (TreeKeyIdx *) mod->CreateKey();
+		tree_key_idx->setText(mykey);
+                mod->SetKey(tree_key_idx);
+		(char*)mod;
+		retval = tree_key_idx->getOffset();
+		delete tree_key_idx;
+	}
+        return retval;
+}
+
+
 unsigned long BackEnd::get_treekey_offset(void) {
         if (tree_key) 
                 return tree_key->getOffset();
@@ -1393,7 +1454,6 @@ void BackEnd::save_module_key(char *mod_name, char *key) {
 	char *mod_name_lower =  g_ascii_strdown(mod_name, strlen(mod_name));	
 	char *conffile = g_strdup_printf("%s/%s.conf",main_mgr->configPath,mod_name_lower);
 	SWConfig *myConfig = new SWConfig(conffile);
-	
 	section = myConfig->Sections.find(mod_name);
 	if (section != myConfig->Sections.end()) {
 		entry =  section->second. find("CipherKey");
