@@ -56,6 +56,8 @@ extern gboolean do_display;
 
 static 
 gboolean save_through_persist_file(EDITOR * e, const gchar * filename);
+static 
+void editor_load_note(EDITOR * e, const gchar * module_name, const gchar * key);
 
 struct _editor {
 	GtkWidget *window;
@@ -94,11 +96,13 @@ gboolean editor_is_dirty(EDITOR * e)
 	gboolean rv;
 
 	CORBA_exception_init(&ev);
-	rv = e->is_changed
+/*	rv = e->is_changed
 	    || (GNOME_GtkHTML_Editor_Engine_hasUndo(e->engine, &ev) &&
 		!GNOME_GtkHTML_Editor_Engine_runCommand(e->engine,
 							"is-saved",
-							&ev));
+							&ev)); */
+	rv = GNOME_GtkHTML_Editor_Engine_hasUndo(e->engine, &ev);
+	
 	CORBA_exception_free(&ev);
 
 	return rv;
@@ -155,6 +159,7 @@ delete_note_cb(GtkWidget * widget, gpointer data)
 		test = gui_alert_dialog(info);
 		if (test == GS_YES) {
 			main_delete_note(e->module, e->key);
+			load_through_persist_stream("", e);
 		}
 		g_free(info);
 		g_free(buf);
@@ -222,8 +227,10 @@ load_through_persist_file(EDITOR * e, const gchar * filename)
 	CORBA_Environment ev;
 
 	CORBA_exception_init(&ev);
-	
+
+#ifdef DEBUG	
 	g_message(filename);
+#endif
 
 	Bonobo_PersistFile_load(e->persist_file_interface, filename, &ev);
 
@@ -1216,7 +1223,6 @@ static GtkWidget *container_create(const gchar * window_title,
 	if (servant) {
 		impl = bonobo_object(servant);
 		if (impl) {
-			g_message("impl");
 			editor->html_widget =
 			    g_object_get_data(G_OBJECT(impl),
 					      "html-widget");
