@@ -65,7 +65,8 @@
 
 
 gboolean shift_key_presed = FALSE;
-
+guint scroll_adj_signal;
+GtkAdjustment* adjustment;
 static void create_menu(void); //GdkEventButton * event);
 
 static GtkTextBuffer *text_buffer;
@@ -483,6 +484,28 @@ static void create_text_tags(GtkTextBuffer * buffer)
 }
 
 
+static
+void adj_changed(GtkAdjustment * adjustment1, gpointer user_data) 
+
+{
+	static int scroll = 1;
+	if(!settings.chapter_scroll) return;
+	if(scroll && (adjustment1->value <= adjustment1->lower)) {
+#ifdef DEBUG
+		g_message("\ntop: %g\n",adjustment1->value);
+#endif
+		gui_navbar_handle_spinbutton_click(1, 0);
+		scroll = 0;
+	} else if(scroll && (adjustment1->value >= (adjustment1->upper - adjustment1->page_size))) {
+#ifdef DEBUG
+		g_message("\nvalue + page_size: %g\n",adjustment1->value + adjustment1->page_size);
+#endif
+		gui_navbar_handle_spinbutton_click(1, 1);
+		scroll = 0;
+		gtk_adjustment_set_value(adjustment,2);
+	} else 	scroll = 1;
+}
+
 /******************************************************************************
  * Name
  *   gui_create_bible_pane
@@ -503,7 +526,6 @@ GtkWidget *gui_create_bible_pane(void)
 {
 	GtkWidget *notebook_text;
 	GtkWidget *scrolledwindow;
-	//GtkWidget *eventbox1;
 	GtkWidget *frame;
 	
 	notebook_text = gtk_notebook_new();
@@ -530,6 +552,11 @@ GtkWidget *gui_create_bible_pane(void)
 				       (scrolledwindow),
 				       GTK_POLICY_AUTOMATIC,
 				       GTK_POLICY_AUTOMATIC);
+	adjustment = gtk_scrolled_window_get_vadjustment
+                                            (GTK_SCROLLED_WINDOW(scrolledwindow));
+	scroll_adj_signal = g_signal_connect(GTK_OBJECT(adjustment), "value-changed",
+				G_CALLBACK(adj_changed),
+				NULL);
 	
 	widgets.html_text = gtk_html_new();
 	gtk_widget_show(widgets.html_text);
@@ -1066,13 +1093,6 @@ static GnomeUIInfo menu1_uiinfo[] = {
 	 NULL,
 	 (gpointer) on_unlock_module_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, "gnome-stock-authentication",
-	 0, (GdkModifierType) 0, NULL},
-	GNOMEUIINFO_SEPARATOR,
-	{
-	 GNOME_APP_UI_TOGGLEITEM, N_("Show Tabs"),
-	 NULL,
-	 (gpointer) on_show_tabs_activate, NULL, NULL,
-	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, (GdkModifierType) 0, NULL},	
 	GNOMEUIINFO_END
 };
