@@ -127,7 +127,7 @@ static gboolean on_comm_button_press_event(GtkWidget * widget,
  *  on_button_release_event
  *
  * Synopsis
- *   #include "_bibletext.h"
+ *   #include "commentary.h"
  *
  *  gboolean on_button_release_event(GtkWidget * widget,
 			    GdkEventButton * event, DIALOG_DATA * t)
@@ -186,7 +186,7 @@ static gboolean on_comm_button_release_event(GtkWidget * widget,
 		if (!in_url)
 			break;
 #ifdef USE_GTKHTML38
-		url = gtk_html_get_url_at (GTK_HTML(widgets.html_text),		
+		url = gtk_html_get_url_at (GTK_HTML(widgets.html_comm),		
 								event->x,
 								event->y);
 #else
@@ -194,10 +194,14 @@ static gboolean on_comm_button_release_event(GtkWidget * widget,
 					 event->x,
 					 event->y);
 #endif
-		if(strstr(url,"sword://")) {
-			gchar **work_buf = g_strsplit (url,"/",4);
-			gui_open_passage_in_new_tab(work_buf[3]);
-			g_strfreev(work_buf);
+		if (url) {
+			if(strstr(url,"sword://")) {
+				gchar **work_buf = g_strsplit (url,"/",4);
+				gui_open_passage_in_new_tab(work_buf[3]);
+				g_strfreev(work_buf);
+			}
+		} else {
+			gui_generic_warning("Middle-click invalid.");
 		}
 		break;
 	case 3:
@@ -238,8 +242,7 @@ GtkWidget *gui_create_commentary_pane(void)
 {
 	GtkWidget *box_comm;
 	GtkWidget *scrolledwindow;
-	GtkWidget *eventbox1;	
-	
+	GtkWidget *eventbox1;
 	box_comm = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(box_comm);
 /*
@@ -283,7 +286,6 @@ GtkWidget *gui_create_commentary_pane(void)
 	gtk_widget_show(widgets.html_comm);
 	gtk_container_add(GTK_CONTAINER(scrolledwindow),
 			  widgets.html_comm);
-
 	g_signal_connect(GTK_OBJECT(widgets.html_comm), "link_clicked",
 				   G_CALLBACK(gui_link_clicked),
 				   NULL);
@@ -363,6 +365,7 @@ static void
 on_set_module_font_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
 	gui_set_module_font(settings.CommWindowModule);
+	main_display_commentary(settings.CommWindowModule,settings.currentverse);
 }
 
 
@@ -527,6 +530,49 @@ static void on_view_mod_activate(GtkMenuItem * menuitem,
 }
 
 
+/******************************************************************************
+ * Name
+ *  on_book_heading_activate
+ *
+ * Synopsis
+ *   #include "gui/bibletext_menu.h"
+ *
+ *  void on_book_heading_activate(GtkMenuItem * menuitem, DIALOG_DATA * vt)	
+ *
+ * Description
+ *   
+ *
+ * Return value
+ *   void
+ */
+
+static void on_book_heading_activate(GtkMenuItem * menuitem, gpointer data)
+{
+	main_book_heading(settings.CommWindowModule);
+}
+
+
+/******************************************************************************
+ * Name
+ *  on_chapter_heading_activate
+ *
+ * Synopsis
+ *   #include "gui/bibletext_menu.h"
+ *
+ *  void on_chapter_heading_activate(GtkMenuItem * menuitem, DIALOG_DATA * vt)	
+ *
+ * Description
+ *   
+ *
+ * Return value
+ *   void
+ */
+
+static void on_chapter_heading_activate(GtkMenuItem * menuitem, gpointer data)
+{
+	main_chapter_heading(settings.CommWindowModule);
+}
+
 
 static void on_add_bookmark_activate(GtkMenuItem * menuitem,
 				 gpointer user_data)
@@ -766,19 +812,24 @@ static GnomeUIInfo menu1_uiinfo[] = {
 	 lookup_selection_menu_uiinfo, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, "gtk-find",
 	 0, (GdkModifierType) 0, NULL},
+	{
+	 GNOME_APP_UI_ITEM, N_("Display Book Heading"),
+	 NULL,
+	 (gpointer) on_book_heading_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, "gtk-open",
+	 0, (GdkModifierType) 0, NULL},
+        {
+	 GNOME_APP_UI_ITEM, N_("Display Chapter Heading"),
+	 NULL,
+	 (gpointer) on_chapter_heading_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, "gtk-open",
+	 0, (GdkModifierType) 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Unlock This Module"),
 	 NULL,
 	 (gpointer) on_unlock_module_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, "gnome-stock-authentication",
 	 0, (GdkModifierType) 0, NULL},
-	GNOMEUIINFO_SEPARATOR,
-	{
-	 GNOME_APP_UI_TOGGLEITEM, N_("Show Tabs"),
-	 NULL,
-	 (gpointer) on_show_tabs_activate, NULL, NULL,
-	 GNOME_APP_PIXMAP_NONE, NULL,
-	 0, (GdkModifierType) 0, NULL},
 	GNOMEUIINFO_END
 };
 
@@ -811,8 +862,8 @@ void gui_create_pm_commentary(void)
 	gtk_widget_hide(module_options_menu_uiinfo[10].widget);	//"hebrew_cantillation"        
 	gtk_widget_hide(module_options_menu_uiinfo[11].widget);	//"headings"    
 	gtk_widget_hide(module_options_menu_uiinfo[12].widget);	//"variants"   
-	gtk_widget_hide(menu1_uiinfo[7].widget);	//"unlock_module"
-	gtk_widget_hide(menu1_uiinfo[8].widget);
+	//gtk_widget_hide(menu1_uiinfo[7].widget);	//"unlock_module"
+	//gtk_widget_hide(menu1_uiinfo[8].widget);
 	gtk_widget_hide(menu1_uiinfo[9].widget);
 
 
@@ -936,7 +987,7 @@ void gui_create_pm_commentary(void)
 		
 	}
 	if(main_has_cipher_tag(mod_name))
-		gtk_widget_show(menu1_uiinfo[7].widget);
+		gtk_widget_show(menu1_uiinfo[9].widget);
 	
 	
 	/* 
