@@ -346,7 +346,7 @@ void dict_key_entry_changed(GtkEntry * entry, gpointer data)
 	gchar *buf = NULL;
 	
 	buf = (gchar*)gtk_entry_get_text(entry);
-	
+//	g_message("dict_key_entry_changed: %s",buf);
 	if(strlen(buf) < 2 )
 		return;
 	
@@ -367,7 +367,9 @@ void button_forward_clicked(GtkButton * button, gpointer user_data)
 static void on_entry_activate(GtkEntry * entry,
 				   gpointer user_data)
 {
+#ifdef DEBUG
 	g_message("on_entry_activate");
+#endif
 }
 
 
@@ -1025,19 +1027,19 @@ static GnomeUIInfo menu1_uiinfo[] = {
 	 lookup_selection_menu_uiinfo, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, "gtk-find",
 	 0, (GdkModifierType) 0, NULL},
-	{
-	 GNOME_APP_UI_ITEM, N_("Unlock This Module"),
-	 NULL,
-	 (gpointer) on_unlock_module_activate, NULL, NULL,
-	 GNOME_APP_PIXMAP_STOCK, "gnome-stock-authentication",
-	 0, (GdkModifierType) 0, NULL},
-	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_TOGGLEITEM, N_("Show Tabs"),
 	 NULL,
 	 (gpointer) on_show_tabs_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, (GdkModifierType) 0, NULL},
+	GNOMEUIINFO_SEPARATOR,
+	{
+	 GNOME_APP_UI_ITEM, N_("Unlock This Module"),
+	 NULL,
+	 (gpointer) on_unlock_module_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, "gnome-stock-authentication",
+	 0, (GdkModifierType) 0, NULL},
 	GNOMEUIINFO_END
 };
 
