@@ -444,7 +444,7 @@ static void
 on_set_module_font_activate(GtkMenuItem * menuitem, gpointer user_data)
 {
 	gui_set_module_font(settings.book_mod);
-	//gui_display_text(settings.currentverse);
+	main_display_book(settings.book_mod,xml_get_value( "keys", "offset"));
 }
 
 
@@ -845,19 +845,19 @@ static GnomeUIInfo menu1_uiinfo[] = {
 	 lookup_selection_menu_uiinfo, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, "gtk-find",
 	 0, (GdkModifierType) 0, NULL},
-	{
-	 GNOME_APP_UI_ITEM, N_("Unlock This Module"),
-	 NULL,
-	 (gpointer) on_unlock_module_activate, NULL, NULL,
-	 GNOME_APP_PIXMAP_STOCK, "gnome-stock-authentication",
-	 0, (GdkModifierType) 0, NULL},
-	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_TOGGLEITEM, N_("Show Tabs"),
 	 NULL,
 	 (gpointer) on_show_tabs_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, (GdkModifierType) 0, NULL},
+	GNOMEUIINFO_SEPARATOR,
+	{
+	 GNOME_APP_UI_ITEM, N_("Unlock This Module"),
+	 NULL,
+	 (gpointer) on_unlock_module_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, "gnome-stock-authentication",
+	 0, (GdkModifierType) 0, NULL},
 	GNOMEUIINFO_END
 };
 
