@@ -49,7 +49,6 @@
 #include "gui/studypad.h"
 #include "gui/parallel_view.h"
 #include "gui/dialog.h"
-#include "gui/hints.h"
 #include "gui/widgets.h"
 #include "gui/sidebar.h"
 #include "gui/mod_mgr.h"
@@ -88,8 +87,8 @@ void frontend_init(void)
 #endif
 
 	
-	hint.in_popup = FALSE;
-	hint.use_hints = FALSE;
+//	hint.in_popup = FALSE;
+//	hint.use_hints = FALSE;
 	
 	settings.comm_showing = TRUE;
 	settings.displaySearchResults = FALSE;
@@ -207,12 +206,9 @@ void frontend_display(void)
 				       (widgets.viewpreview_item),
 				       settings.showpreview);
 	gui_show_hide_preview(settings.showpreview);
-	/* showing the devotional must come after the the app is shown or
-	 *  it will mess up the sidebar display
-	 */
-	/*
-	 * FIXME: maybe we need to move the devotional?
-	 */
+	gui_show_hide_texts(settings.showtexts);
+	gui_show_hide_dicts(settings.showdicts);
+	gui_show_hide_comms(settings.showcomms);
 	if (settings.showdevotional) {
 		main_display_devotional();
 	}
@@ -245,6 +241,8 @@ void frontend_display(void)
 					      0);
 */
 	gtk_widget_grab_focus (sidebar.module_list);
+	
+
 #ifdef DEBUG	
 	g_print("%s\n\n", _("done"));
 #endif
@@ -268,7 +266,7 @@ void frontend_display(void)
  */
 
 void shutdown_frontend(void)
-{
+{		
 	RESULTS *list_item;
 	if(pixbufs->pixbuf_closed)
 		g_object_unref(pixbufs->pixbuf_closed);
