@@ -27,6 +27,7 @@
 #include <gtk/gtk.h>
 
 #include "gui/gui.h"
+#include "gui/session.h"
 
 void gui_init(int argc, char *argv[])
 {
@@ -39,8 +40,7 @@ void gui_init(int argc, char *argv[])
                       argc, argv,
                       GNOME_PROGRAM_STANDARD_PROPERTIES,
                       NULL);
-	//gnome_init("GnomeSword", VERSION, argc, argv);
-//	gdk_rgb_init ();
+	gs_session_init(argv[0]);
 }
 
 void gui_main(void)
