@@ -47,7 +47,6 @@
 #include "gui/cipher_key_dialog.h"
 #include "gui/dialog.h"
 #include "gui/bibletext.h"
-#include "gui/hints.h"
 #include "gui/widgets.h"
 #include "gui/tabbed_browser.h"
 
@@ -377,8 +376,18 @@ gchar *gui_button_press_lookup(GtkWidget * html_widget)
 	if (!html->in_selection) {
 		gtk_html_select_word(html);
 		key = gtk_html_get_selection_html(html, &len);
+		if(!len) {
+			return NULL;
+		}
+		
+		
 		buf = main_get_striptext_from_string(settings.MainWindowModule, 
-						key);		
+						key);	
+		
+#ifdef DEBUG
+		g_message(buf);
+#endif
+		if(buf == NULL) return;
 		key = g_strdelimit(buf, ".,\"<>;:?", ' ');
 		key = g_strstrip(key);
 		len = strlen(key);
