@@ -24,7 +24,6 @@
 #endif
 
 #include <gnome.h>
-//#include <gal/shortcut-bar/e-shortcut-bar.h>
 
 #ifdef USE_GTKHTML38
 #include "editor/html-editor.h"
@@ -33,7 +32,6 @@
 #include "gui/about_gnomesword.h"
 #include "gui/about_sword.h"
 #include "gui/gnomesword.h"
-#include "gui/hints.h"
 #include "gui/html.h"
 #include "gui/main_window.h"
 #include "gui/main_menu.h"
@@ -96,7 +94,7 @@ void on_help_contents_activate(GtkMenuItem * menuitem,
 {	
 	GError *error = NULL;
 	
-	if (gnome_help_display ((const gchar*)"gnomesword-manual.xml", 
+	if (gnome_help_display ((const gchar*)"gnomesword.xml", 
 			NULL, &error) == FALSE) {
 		g_warning(error->message);
 		g_error_free (error);        
@@ -305,6 +303,33 @@ static void on_read_aloud_activate(GtkCheckMenuItem * menuitem,
 	settings.readaloud = menuitem->active;
 	xml_set_value("GnomeSword", "misc", "readaloud",
 		      (settings.readaloud ? "1" : "0"));
+	if (settings.readaloud)
+		main_display_bible(NULL, settings.currentverse);
+}
+
+/******************************************************************************
+ * Name
+ *  on_show_verse_numbers_activate
+ *
+ * Synopsis
+ *   #include "gui/main_menu.h"
+ *
+ *   void on_show_verse_numbers_activate(GtkMenuItem *menuitem, gpointer user_data)	
+ *
+ * Description
+ *   toggle showing verse numbers together.
+ *
+ * Return value
+ *   void
+ */
+
+static void on_show_verse_numbers_activate(GtkCheckMenuItem * menuitem,
+					   gpointer user_data)
+{
+	settings.showversenum = menuitem->active;
+	xml_set_value("GnomeSword", "misc", "showversenum",
+		      (settings.showversenum ? "1" : "0"));
+	main_display_bible(NULL, settings.currentverse);
 }
 
 /******************************************************************************
@@ -651,18 +676,18 @@ static void open_studypad(GtkMenuItem * menuitem, gpointer user_data)
 
 static GnomeUIInfo file1_menu_uiinfo[] = {
 	{
-	 GNOME_APP_UI_ITEM, N_("Open StudyPad"),
+	 GNOME_APP_UI_ITEM, N_("Open Study_Pad"),
 	 N_("Open the StudyPad editor"),
 	 open_studypad, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
-	{ GNOME_APP_UI_ITEM, N_("Open Session"),
+	{ GNOME_APP_UI_ITEM, N_("_Open Session"),
 	  N_("Open a saved session"),
 	  on_load_tabs, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_OPEN,
 	  0, 0, NULL},
-  	{ GNOME_APP_UI_ITEM, N_("Save Session"),
+  	{ GNOME_APP_UI_ITEM, N_("_Save Session"),
 	  N_("Save the current session to a file"),
 	  on_save_tabs, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_SAVE,
@@ -776,6 +801,12 @@ static GnomeUIInfo view1_menu_uiinfo[] = {
 	 NULL, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, (GdkModifierType) 0, NULL},
+	{
+	 GNOME_APP_UI_TOGGLEITEM, N_("Show Verse _Numbers"),
+	 NULL,
+	 NULL, NULL, NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, (GdkModifierType) 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("_Attach/Detach Sidebar"),
@@ -884,6 +915,7 @@ void gui_create_main_menu(GtkWidget * app)
 	widgets.versestyle_item = view1_menu_uiinfo[7].widget;
 	widgets.pinnedtabs_item = view1_menu_uiinfo[8].widget;
 	widgets.readaloud_item = view1_menu_uiinfo[9].widget;
+	widgets.showversenum_item = view1_menu_uiinfo[10].widget;
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
 				       (widgets.versestyle_item),
 				       settings.versestyle);
@@ -893,6 +925,9 @@ void gui_create_main_menu(GtkWidget * app)
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
 				       (widgets.readaloud_item),
 				       settings.readaloud);
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
+				       (widgets.showversenum_item),
+				       settings.showversenum);
 	
 	g_signal_connect(GTK_OBJECT(widgets.versestyle_item),
 			   "toggled",
@@ -906,6 +941,10 @@ void gui_create_main_menu(GtkWidget * app)
 			   "toggled",
 			   G_CALLBACK(on_read_aloud_activate),
 			   NULL);
+	g_signal_connect(GTK_OBJECT(widgets.showversenum_item),
+			   "toggled",
+			   G_CALLBACK(on_show_verse_numbers_activate),
+			   NULL);
 }
 
 /******************************************************************************
