@@ -106,6 +106,7 @@ static gboolean dot_sword;
 static const gchar *destination;
 static gboolean have_configs;
 static gboolean have_changes;
+static gboolean need_update;
 static gint current_page;
 static gint response;
 static GdkPixbuf *INSTALLED;
@@ -134,12 +135,12 @@ GladeXML *gxml;
 
 static void create_pixbufs(void)
 {
-	INSTALLED = gtk_widget_render_icon(widgets.app,
+	INSTALLED = gtk_widget_render_icon(dialog,
 					   GTK_STOCK_APPLY,
 					   GTK_ICON_SIZE_MENU, NULL);
 	LOCKED = gdk_pixbuf_new_from_file(PACKAGE_PIXMAPS_DIR
 					  "/epiphany-secure.png", NULL);
-	BLANK = gtk_widget_render_icon(widgets.app,
+	BLANK = gtk_widget_render_icon(dialog,
 				       "gnome-stock-blank",
 				       GTK_ICON_SIZE_MENU, NULL);
 }
@@ -324,7 +325,7 @@ static void remove_install_modules(GList * modules, gboolean install)
 	gtk_widget_show(button_close);
 	switch(current_page) {
 		case 3:
-			gtk_widget_show(button1);
+			if(need_update) gtk_widget_show(button1);
 			gtk_widget_show(button2);
 		break;
 		case 4:
@@ -535,6 +536,7 @@ static void add_language_folder(GtkTreeModel * model, GtkTreeIter iter,
 	GError *error = NULL;
 	gboolean valid;
 
+		
 	if ((!g_ascii_isalnum(language[0])) || (language == NULL))
 		language = N_("Unknown");
 
@@ -768,6 +770,12 @@ static void response_refresh(void)
 	load_module_tree(GTK_TREE_VIEW(treeview), TRUE);
 	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(progressbar_refresh), _("Finished"));
 	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(progressbar_refresh), 0);
+	if(!need_update) {
+		gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook1), 3);
+		gtk_widget_hide(button1);
+		gtk_widget_show(button2);
+		gtk_widget_hide(button3);
+	}
 }
 
 /******************************************************************************
@@ -788,13 +796,15 @@ static void response_refresh(void)
 
 static void response_close(void)
 {
-	GString *str = g_string_new(NULL);
-	
-	gtk_widget_destroy(GTK_WIDGET(dialog));
-	g_string_printf(str, "%s/dirlist", settings.homedir);
-	if (mod_mgr_check_for_file(str->str))
-		g_warning(str->str);
-	g_string_free(str,TRUE);
+	if(need_update) {
+		GString *str = g_string_new(NULL);
+		
+		gtk_widget_destroy(GTK_WIDGET(dialog));
+		g_string_printf(str, "%s/dirlist", settings.homedir);
+		if (mod_mgr_check_for_file(str->str))
+			g_warning(str->str);
+		g_string_free(str,TRUE);
+	}
 }
 
 
@@ -1071,18 +1081,18 @@ static GtkTreeModel *create_model_to_first(void)
 	gtk_tree_store_set(model, &iter, 0, "SWORD", -1);
 
 	gtk_tree_store_append(model, &child_iter, &iter);
-	gtk_tree_store_set(model, &child_iter, 0, "Configure", 1, 1,
+	gtk_tree_store_set(model, &child_iter, 0, _("Configure"), 1, 1,
 			   -1);
 	gtk_tree_store_append(model, &child_iter, &iter);
-	gtk_tree_store_set(model, &child_iter, 0, "Sources", 1, 2, -1);
+	gtk_tree_store_set(model, &child_iter, 0, _("Sources"), 1, 2, -1);
 
 
 	gtk_tree_store_append(model, &iter, NULL);
-	gtk_tree_store_set(model, &iter, 0, "Modules", -1);
+	gtk_tree_store_set(model, &iter, 0, _("Modules"), -1);
 	gtk_tree_store_append(model, &child_iter, &iter);
-	gtk_tree_store_set(model, &child_iter, 0, "Install", 1, 3, -1);
+	gtk_tree_store_set(model, &child_iter, 0, _("Install"), 1, 3, -1);
 	gtk_tree_store_append(model, &child_iter, &iter);
-	gtk_tree_store_set(model, &child_iter, 0, "Remove", 1, 4, -1);
+	gtk_tree_store_set(model, &child_iter, 0, _("Remove"), 1, 4, -1);
 
 	return GTK_TREE_MODEL(model);
 }
@@ -1568,18 +1578,56 @@ GtkWidget *create_fileselection_local_source(void)
 
 void on_dialog_destroy(GtkObject * object, gpointer user_data)
 {
+#ifdef DEBUG
 	g_message("on_destroy");
+#endif
 	mod_mgr_shut_down();
 	while (gtk_events_pending()) {
 		gtk_main_iteration();
 	} 
-	if(have_changes) {
+	if(have_changes && need_update) {
 		main_update_module_lists();
 		main_load_module_tree(sidebar.module_list);
 	}
 }
 
 
+void on_refresh_clicked(GtkButton * button, gpointer  user_data)
+{
+	response_refresh();
+}
+
+void on_install_clicked(GtkButton * button, gpointer  user_data)
+{
+	GList *modules = NULL;
+	modules = get_list_mods_to_remove_install(INSTALL);
+	while (gtk_events_pending()) {
+		gtk_main_iteration();
+	}
+	remove_install_modules(modules, INSTALL);
+	load_module_tree(GTK_TREE_VIEW(treeview), TRUE);
+	while (gtk_events_pending()) {
+		gtk_main_iteration();
+	} 	
+}
+
+void on_remove_clicked(GtkButton * button, gpointer  user_data)
+{
+	GList *modules = NULL;
+	modules = get_list_mods_to_remove_install(REMOVE);
+	remove_install_modules(modules, REMOVE);
+	load_module_tree(GTK_TREE_VIEW(treeview2), FALSE);	
+}
+
+void on_cancel_clicked(GtkButton * button, gpointer  user_data)
+{
+	mod_mgr_terminate();
+	while (gtk_events_pending()) {
+		gtk_main_iteration();
+	}
+}
+
+
 /******************************************************************************
  * Name
  *   on_mod_mgr_response
@@ -1998,11 +2046,7 @@ void setup_treeviews_install_remove(GtkTreeView * install, GtkTreeView * remove)
 static
 void set_combobox(GtkComboBox * combo)
 {	
-	//GtkTreeIter iter;
 	GtkListStore *store;
-	//GtkCellRenderer *renderer;
-	//gint index = 0;
-	//gint i = 0;
 	
 	store = gtk_list_store_new(1, G_TYPE_STRING);
 	gtk_combo_box_set_model(combo, GTK_TREE_MODEL(store));
@@ -2011,27 +2055,165 @@ void set_combobox(GtkComboBox * combo)
 
 
 static
-void create_module_manager_dialog(void)
+void setup_dialog_action_area(GtkDialog * dialog)
+{	
+	GtkWidget *alignment1;
+	GtkWidget *hbox1;
+	GtkWidget *image1;
+	GtkWidget *label1;
+	GtkWidget *dialog_action_area1 = GTK_DIALOG (dialog)->action_area;
+	
+	gtk_widget_show (dialog_action_area1);
+	gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area1), GTK_BUTTONBOX_END);
+
+	/* responce buttons */
+/* close */	
+	button_close = gtk_button_new_from_stock ("gtk-close");
+	gtk_widget_show (button_close);
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_close, GTK_RESPONSE_CLOSE);
+	GTK_WIDGET_SET_FLAGS (button_close, GTK_CAN_DEFAULT);
+/* connect/refresh */	
+	button1 = gtk_button_new_from_stock ("gtk-connect");
+	gtk_box_pack_start(GTK_BOX(dialog_action_area1),button1,FALSE, FALSE,0);
+	g_signal_connect(button1, "clicked", G_CALLBACK(on_refresh_clicked), NULL);
+	//gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button1, 301);
+	//GTK_WIDGET_SET_FLAGS (button1, GTK_CAN_DEFAULT); 
+/* install */	
+	button2 = gtk_button_new ();
+	gtk_box_pack_start(GTK_BOX(dialog_action_area1),button2,FALSE, FALSE,0);
+	g_signal_connect(button2, "clicked", G_CALLBACK(on_install_clicked), NULL);
+	//gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button2, 303);
+	//GTK_WIDGET_SET_FLAGS (button2, GTK_CAN_DEFAULT);
+
+	alignment1 = gtk_alignment_new (0.5, 0.5, 0, 0);
+	gtk_widget_show (alignment1);
+	gtk_container_add (GTK_CONTAINER (button2), alignment1);
+
+	hbox1 = gtk_hbox_new (FALSE, 2);
+	gtk_widget_show (hbox1);
+	gtk_container_add (GTK_CONTAINER (alignment1), hbox1);
+
+	image1 = gtk_image_new_from_stock ("gtk-add", GTK_ICON_SIZE_BUTTON);
+	gtk_widget_show (image1);
+	gtk_box_pack_start (GTK_BOX (hbox1), image1, FALSE, FALSE, 0);
+
+	label1 = gtk_label_new_with_mnemonic (_("Install"));
+	gtk_widget_show (label1);
+	gtk_box_pack_start (GTK_BOX (hbox1), label1, FALSE, FALSE, 0);
+
+  
+/* remove */	
+	button3 =  gtk_button_new_from_stock ("gtk-remove");
+	gtk_box_pack_start(GTK_BOX(dialog_action_area1),button3,FALSE, FALSE,0);
+	g_signal_connect(button3, "clicked", G_CALLBACK(on_remove_clicked), NULL);
+	//gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button3, 302);
+	//GTK_WIDGET_SET_FLAGS (button3, GTK_CAN_DEFAULT);
+/* cancel */	
+	button_cancel =  gtk_button_new_from_stock ("gtk-cancel");
+	gtk_box_pack_start(GTK_BOX(dialog_action_area1),button_cancel,FALSE, FALSE,0);
+	g_signal_connect(button_cancel, "clicked", G_CALLBACK(on_cancel_clicked), NULL);
+	//gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button_cancel, GTK_RESPONSE_CANCEL);
+	//GTK_WIDGET_SET_FLAGS (button_cancel, GTK_CAN_DEFAULT);
+	
+}
+
+static void setup_ui_labels()
+{
+
+	GString *str = g_string_new(NULL);
+	gchar *path = NULL;
+	gchar *homedir = NULL;
+		
+	if((homedir = getenv("HOME")) == NULL) {
+		
+		
+	}	
+	have_changes = FALSE;
+	g_string_printf(str, "%s/%s", homedir,
+			".sword/InstallMgr/InstallMgr.conf");
+	if (!mod_mgr_check_for_file(str->str)) {
+		have_configs = FALSE;
+		mod_mgr_init_config();
+	}
+	have_configs = TRUE;
+	mod_mgr_init(NULL);
+	g_string_printf(str, "%s/%s", homedir, ".sword");
+	gtk_label_set_text(GTK_LABEL(label_home), str->str);
+
+	path = main_module_mgr_get_path_to_mods();
+	gtk_label_set_text(GTK_LABEL(label_system), path);
+	if (access(path, W_OK) == -1) {
+		g_print("%s is write protected\n", path);
+		gtk_widget_set_sensitive(label_system, FALSE);
+		gtk_widget_set_sensitive(radiobutton4, FALSE);
+	} else {
+		gtk_widget_set_sensitive(label_system, TRUE);
+		gtk_widget_set_sensitive(radiobutton4, TRUE);
+	}
+	create_pixbufs();
+	load_source_treeviews();
+	g_string_free(str, TRUE);
+	g_free(path);
+}
+
+static
+GtkWidget *create_module_manager_dialog(gboolean first_run)
 {
 	gchar *glade_file;
+	GtkWidget *dialog_vbox;
+	GtkWidget *hpaned;
 	GtkWidget *chooser;
 	GtkWidget *button5;
 	GtkWidget *button6;
 	GtkWidget *button7;
 	GtkWidget *button8;
+	GtkWidget *widget;
 	gint index = 0;
+	GString *str = g_string_new(NULL);
+	gchar *homedir = NULL;
+	gchar *path = NULL;
 
 	glade_file = gui_general_user_file ("module-manager.glade", FALSE);
 	g_return_if_fail(glade_file != NULL);
+#ifdef DEBUG
 	g_message(glade_file);
+#endif
 	
 	/* build the widget */
-	gxml = glade_xml_new (glade_file, "dialog", NULL);
+	if(first_run) {		
+		gxml = glade_xml_new (glade_file, "hpaned1", NULL);       //"dialog", NULL);
+	} else {
+		gxml = glade_xml_new (glade_file, "dialog", NULL);
+		
+	}
+	//gxml = glade_xml_new (glade_file, "hpaned1", NULL);       //"dialog", NULL);
 	g_free (glade_file);
 	g_return_if_fail (gxml != NULL);
 
 	/* lookup the root widget */
-	dialog = glade_xml_get_widget (gxml, "dialog");
+	if(first_run) {		
+		hpaned = glade_xml_get_widget (gxml, "hpaned1"); 
+		
+		dialog = gtk_dialog_new();
+		gtk_widget_show(dialog);
+		gtk_widget_set_size_request(dialog, 500, 341);
+		dialog_vbox = GTK_DIALOG(dialog)->vbox;
+		gtk_widget_show(dialog_vbox);
+		gtk_box_pack_start(GTK_BOX(dialog_vbox),hpaned, TRUE, TRUE, 6);
+		widget = glade_xml_get_widget (gxml, "scrolledwindow1");
+		gtk_widget_hide(widget);
+		/* setup dialog action area */
+		setup_dialog_action_area(GTK_DIALOG (dialog));
+	} else {
+		dialog =  glade_xml_get_widget (gxml, "dialog");
+		/* responce buttons */
+		button_close = glade_xml_get_widget (gxml, "button1"); /* close */
+		button_cancel = glade_xml_get_widget (gxml, "button12"); /* close */
+		button1 = glade_xml_get_widget (gxml, "button2"); /* refresh */
+		button2 = glade_xml_get_widget (gxml, "button3"); /* install */
+		button3 = glade_xml_get_widget (gxml, "button9"); /* remove */
+	}
+		
 	g_signal_connect(dialog, "response",
 			 G_CALLBACK(on_mod_mgr_response), NULL);
 	g_signal_connect(dialog, "destroy",
@@ -2041,6 +2223,9 @@ void create_module_manager_dialog(void)
 			 G_CALLBACK(), NULL);
 */
 	
+	/* progress bars */
+	progressbar_refresh = glade_xml_get_widget (gxml, "progressbar1"); /* refresh */
+			
 	/* treeviews */
 	treeview1 = glade_xml_get_widget (gxml, "treeview1");
 	setup_treeview_main(GTK_TREE_VIEW(treeview1));
@@ -2056,16 +2241,13 @@ void create_module_manager_dialog(void)
 	/* notebook */
 	notebook1 = glade_xml_get_widget (gxml, "notebook1");		
 	g_signal_connect(notebook1, "switch_page",
-			 G_CALLBACK(on_notebook1_switch_page), NULL);
+			 G_CALLBACK(on_notebook1_switch_page), NULL);	
+	if(first_run) gtk_notebook_set_current_page(GTK_NOTEBOOK(notebook1),1);
 	/* labels */
 	label_home = glade_xml_get_widget (gxml, "label_home");
 	label_system = glade_xml_get_widget (gxml, "label_sword_sys");
-	/* responce buttons */
-	button_close = glade_xml_get_widget (gxml, "button1"); /* close */
-	button_cancel = glade_xml_get_widget (gxml, "button12"); /* close */
-	button1 = glade_xml_get_widget (gxml, "button2"); /* refresh */
-	button2 = glade_xml_get_widget (gxml, "button3"); /* install */
-	button3 = glade_xml_get_widget (gxml, "button9"); /* remove */
+	
+	
 	/* sources buttons */
 	button5 = glade_xml_get_widget (gxml, "button5"); /* close */
 	button6 = glade_xml_get_widget (gxml, "button6"); /* close */
@@ -2079,7 +2261,7 @@ void create_module_manager_dialog(void)
 			 G_CALLBACK(on_button7_clicked), NULL);
 	g_signal_connect(button8, "clicked",
 			 G_CALLBACK(on_button8_clicked), NULL);
-			
+	
 	/* combo box entrys */
 	combo_entry1 = glade_xml_get_widget (gxml, "comboboxentry1"); /* local soruce */
 	set_combobox(GTK_COMBO_BOX(combo_entry1));
@@ -2095,17 +2277,17 @@ void create_module_manager_dialog(void)
 			 */
 	g_signal_connect(radiobutton2, "toggled",
 			 G_CALLBACK(on_radiobutton2_toggled), NULL);
+	if(first_run) 
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radiobutton2),TRUE);
+	
 /*	g_signal_connect(radiobutton_dest, "toggled",
 			 G_CALLBACK(), NULL);
 	g_signal_connect(radiobutton4, "toggled",
 			 G_CALLBACK(), NULL);
-*/
-	/* progress bars */
-	progressbar_refresh = glade_xml_get_widget (gxml, "progressbar1"); /* refresh */
-/*	
-	glade_xml_signal_autoconnect_full
-		(gxml, (GladeXMLConnectFunc)gui_glade_signal_connect_func, NULL);
-		*/
+*/	
+	setup_ui_labels();
+		
+	return dialog;
 }
 
 
@@ -2127,47 +2309,40 @@ void create_module_manager_dialog(void)
 
 void gui_open_mod_mgr(void)
 {
-	//GtkWidget *dlg;
-	GString *str = g_string_new(NULL);
-	gchar *path = NULL;
-
-	have_changes = FALSE;
-	g_string_printf(str, "%s/%s", settings.homedir,
-			".sword/InstallMgr/InstallMgr.conf");
-
-	if (!mod_mgr_check_for_file(str->str)) {
-		have_configs = FALSE;
-		mod_mgr_init_config();
-	}
-	have_configs = TRUE;
-	/*
-	   if (g_thread_supported ())
-	   g_print("g_thread_supported\n");
-	 */
-	mod_mgr_init(NULL);
-	//dlg = create_dialog();
-	create_module_manager_dialog();
-	
-	g_string_printf(str, "%s/%s", settings.homedir, ".sword");
-	gtk_label_set_text(GTK_LABEL(label_home), str->str);
-
-	path = main_get_path_to_mods();
-	gtk_label_set_text(GTK_LABEL(label_system), path);
-	if (access(path, W_OK) == -1) {
-		g_print("%s is write protected\n", path);
-		gtk_widget_set_sensitive(label_system, FALSE);
-		gtk_widget_set_sensitive(radiobutton4, FALSE);
-	} else {
-		gtk_widget_set_sensitive(label_system, TRUE);
-		gtk_widget_set_sensitive(radiobutton4, TRUE);
-	}
-
-	create_pixbufs();
-	load_source_treeviews();
-	g_string_free(str, TRUE);
+	need_update = TRUE;
+	create_module_manager_dialog(FALSE);
 }
 
 
+/******************************************************************************
+ * Name
+ *   gui_open_mod_mgr_initial_run
+ *
+ * Synopsis
+ *   #include "gui/mod_mgr.h"
+ *
+ *   void gui_open_mod_mgr_initial_run(void)
+ *
+ * Description
+ *   
+ *
+ * Return value
+ *   void
+ */
+
+void gui_open_mod_mgr_initial_run(void)
+{
+	GtkWidget *dlg;
+	need_update = FALSE;
+	//const char *lang = getenv("LANG");	
+	//if (!lang) lang="C";
+	//main_module_mgr_set_sword_locale(lang);
+	//OLD_CODESET = "iso8859-1";
+	dlg = create_module_manager_dialog(TRUE);
+	gtk_dialog_run((GtkDialog *) dlg);
+	gtk_widget_destroy(dlg);
+}
+
 /******************************************************************************
  * Name
  *   gui_update_install_status
