@@ -60,6 +60,7 @@ typedef enum {
 	USE_VERSE_STYLE,
 	USE_PINNED_TABS,
 	READ_ALOUD,
+	SHOW_VERSE_NUM,
 	SHOW_SPLASH_SCREEN,
 	SHOW_BIBLE_PANE,
 	SHOW_COMMENTARY_PANE,
@@ -146,7 +147,10 @@ struct _preferences_check_buttons {
 	GtkWidget *use_default_dictionary;
 	GtkWidget *use_verse_style;
 	GtkWidget *use_pinned_tabs;
+	GtkWidget *use_chapter_scroll;
+	GtkWidget *use_imageresize;
 	GtkWidget *readaloud;
+	GtkWidget *show_verse_num;
 	GtkWidget *show_splash_screen;
 
 	GtkWidget *show_bible_pane;
@@ -264,7 +268,9 @@ static gchar *gdkcolor_to_hex(GdkColor color, gint websafe)
 					color.green/256, 
 					color.blue/256);
 	}
+#ifdef DEBUG
 	g_message(tmpstr);
+#endif
 	return tmpstr;
 }
 
@@ -692,6 +698,35 @@ void on_checkbutton11_toggled(GtkToggleButton * togglebutton, gpointer user_data
 }
 
 
+/******************************************************************************
+ * Name
+ *   on_checkbutton12_toggled
+ *
+ * Synopsis
+ *   #include "preferences_dialog.h"
+ *
+ *   void on_checkbutton12_toggled(GtkToggleButton * togglebutton, gpointer user_data)
+ *
+ * Description
+ *   
+ *   
+ *
+ * Return value
+ *   void
+ */
+
+void on_checkbutton12_toggled(GtkToggleButton * togglebutton, gpointer user_data)
+{
+	xml_set_value("GnomeSword", "misc", "showversenum",
+		      (togglebutton->active ? "1" : "0"));
+	settings.showversenum = atoi(xml_get_value("misc", "showversenum"));
+	
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM
+			       (widgets.showversenum_item),
+			       settings.showversenum);
+}
+
+
 /******************************************************************************
  * Name
  *   on_checkbutton6_toggled
@@ -774,6 +809,65 @@ void on_checkbutton8_toggled(GtkToggleButton * togglebutton, gpointer user_data)
 }
 
 
+
+/******************************************************************************
+ * Name
+ *   on_checkbutton_scroll_toggled
+ *
+ * Synopsis
+ *   #include "preferences_dialog.h"
+ *
+ *   void on_checkbutton_scroll_toggled(GtkToggleButton * togglebutton, gpointer user_data)
+ *
+ * Description
+ *   
+ *   
+ *
+ * Return value
+ *   void
+ */
+
+void on_checkbutton_scroll_toggled(GtkToggleButton * togglebutton, gpointer user_data)
+{
+	gchar *buf;
+	
+	if (togglebutton->active)
+		xml_set_value("GnomeSword", "misc", "chapter-scroll", "1");
+	else
+		xml_set_value("GnomeSword", "misc", "chapter-scroll", "0");
+	buf = xml_get_value("misc", "chapter-scroll");
+	settings.chapter_scroll = atoi(buf);
+}
+
+/******************************************************************************
+ * Name
+ *   on_checkbutton_imageresize_toggled
+ *
+ * Synopsis
+ *   #include "preferences_dialog.h"
+ *
+ *   void on_checkbutton_imageresize_toggled(GtkToggleButton * togglebutton, gpointer user_data)
+ *
+ * Description
+ *   
+ *   
+ *
+ * Return value
+ *   void
+ */
+
+void on_checkbutton_imageresize_toggled(GtkToggleButton * togglebutton, gpointer user_data)
+{
+	gchar *buf;
+	
+	if (togglebutton->active)
+		xml_set_value("GnomeSword", "misc", "imageresize", "1");
+	else
+		xml_set_value("GnomeSword", "misc", "imageresize", "0");
+	buf = xml_get_value("misc", "imageresize");
+	settings.imageresize =  atoi(buf);
+}
+
 /******************************************************************************
  * Name
  *   on_folder_changed
@@ -1528,6 +1622,12 @@ static void setup_check_buttons(void)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
 				     (check_button.show_splash_screen),
 				     settings.showsplash);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
+				     (check_button.use_chapter_scroll),
+				     settings.chapter_scroll);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON
+				     (check_button.use_imageresize),
+				     settings.imageresize);
 
 	g_signal_connect(check_button.enable_tabbed_browsing, "toggled",
 			 G_CALLBACK(on_checkbutton1_toggled), NULL);
@@ -1547,6 +1647,10 @@ static void setup_check_buttons(void)
 			 G_CALLBACK(on_checkbutton7_toggled), NULL);
 	g_signal_connect(check_button.show_splash_screen, "toggled",
 			 G_CALLBACK(on_checkbutton8_toggled), NULL);
+	g_signal_connect(check_button.use_chapter_scroll, "toggled",
+			 G_CALLBACK(on_checkbutton_scroll_toggled), NULL);
+	g_signal_connect(check_button.use_imageresize, "toggled",
+			 G_CALLBACK(on_checkbutton_imageresize_toggled), NULL);
 	
 }
 
@@ -1767,9 +1871,12 @@ static void create_preferences_dialog(void)
 	check_button.use_verse_style = glade_xml_get_widget(gxml, "checkbutton5");
 	check_button.use_pinned_tabs = glade_xml_get_widget(gxml, "checkbutton10");
 	check_button.readaloud = glade_xml_get_widget(gxml, "checkbutton11");
+	check_button.show_verse_num = glade_xml_get_widget(gxml, "checkbutton12");
 	check_button.use_default_dictionary = glade_xml_get_widget(gxml, "checkbutton6");
 	check_button.show_devotion = glade_xml_get_widget(gxml, "checkbutton7");
 	check_button.show_splash_screen = glade_xml_get_widget(gxml, "checkbutton8");
+	check_button.use_chapter_scroll = glade_xml_get_widget(gxml, "checkbutton_scroll");
+	check_button.use_imageresize = glade_xml_get_widget(gxml, "checkbutton_imageresize");
 	setup_check_buttons();
 	/* verse number size */
 	index = get_verse_number_size_index();
