@@ -45,7 +45,6 @@ extern "C" {
 #ifndef USE_GTKHTML38
 #include "editor/editor.h"
 #include "editor/editor-control.h"
-//#include "editor/note_editor.h"
 #endif
 
 #include "gui/bibletext_dialog.h"
@@ -55,7 +54,6 @@ extern "C" {
 #include "gui/display_info.h"
 #include "gui/font_dialog.h"
 #include "gui/sidebar.h"
-#include "gui/hints.h"
 #include "gui/html.h"
 #include "gui/main_window.h"
 #include "gui/note_editor.h"
@@ -126,6 +124,72 @@ extern gboolean gsI_isrunning;	/* information dialog */
 extern gboolean do_display;
 
 
+/******************************************************************************
+ * Name
+ *   main_dialogs_book_heading
+ *
+ * Synopsis
+ *   #include "main/module_dialogs.h"
+ *
+ *   void main_dialogs_book_heading(DIALOG_DATA *d)
+ *
+ * Description
+ *   
+ *
+ * Return value
+ *   void
+ */
+
+void main_dialogs_book_heading(DIALOG_DATA * d)
+{	
+	VerseKey *vkey;		
+	BackEnd* be = (BackEnd*)d->backend;
+	SWMgr *mgr = be->get_display_mgr();
+	
+	be->display_mod = mgr->Modules[d->mod_name];
+	//g_message((char*)be->display_mod->RenderText());
+	vkey = (VerseKey*)(SWKey*)(*be->display_mod);	
+	vkey->Headings(1);
+	vkey->AutoNormalize(0);
+	vkey->Verse(0);
+	vkey->Chapter(0);
+	be->display_mod->Display();
+}
+
+
+/******************************************************************************
+ * Name
+ *   main_dialogs_chapter_heading
+ *
+ * Synopsis
+ *   #include "main/module_dialogs.h"
+ *
+ *   void main_dialogs_chapter_heading(DIALOG_DATA *d)
+ *
+ * Description
+ *   
+ *
+ * Return value
+ *   void
+ */
+
+void main_dialogs_chapter_heading(DIALOG_DATA * d)
+{	
+	VerseKey *vkey;	
+	BackEnd* be = (BackEnd*)d->backend;
+	SWMgr *mgr = be->get_display_mgr();
+	
+	be->display_mod = mgr->Modules[d->mod_name];
+	backend->display_mod->setKey(d->key);
+	vkey = (VerseKey*)(SWKey*)(*be->display_mod);	
+	vkey->Headings(1);
+	vkey->AutoNormalize(0);
+	vkey->Verse(0);
+	//vkey->Chapter(0);
+	be->display_mod->Display();
+}
+
+
 /******************************************************************************
  * Name
  *   main_dialogs_clear_viewer
@@ -1566,7 +1630,9 @@ static gint new_url_handler(DIALOG_DATA * t, const gchar * url, gboolean clicked
 
 gint main_dialogs_url_handler(DIALOG_DATA * t, const gchar * url, gboolean clicked)
 {	
+#ifdef DEBUG
 	g_message("main_dialogs_url_handler url = %s",url);
+#endif
 	if(strstr(url,"passagestudy.jsp") || strstr(url,"gnomesword.url"))
 		return new_url_handler(t,url,clicked);
 	if(strstr(url,"sword://"))
@@ -1736,7 +1802,9 @@ DIALOG_DATA *main_dialogs_open(const gchar * mod_name ,  const gchar * key)
 		main_dialogs_add_book_to_tree(t->tree, t->mod_name, 
 			     TRUE, t);
 		be->set_treekey(t->offset);
+#ifdef DEBUG
 		g_message("offset = %d",t->offset);
+#endif
 	} else
 		be->set_key(t->key);
 	
