@@ -25,6 +25,7 @@
 #include <gnome.h>
 #include <regex.h>
 #include <swbuf.h>
+#include <swmodule.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -37,6 +38,7 @@ extern "C" {
 
 #include "main/search_dialog.h"
 #include "main/settings.h"
+#include "main/sword.h"
 #include "main/xml.h"
  
 #include "gui/search_dialog.h"
@@ -56,7 +58,6 @@ extern "C" {
 static BackEnd *backendSearch;
 
 static gboolean is_running = FALSE;
-
 extern int search_dialog;
 static GList *get_current_list(void);
 static gchar *get_modlist_string(GList * mods);
@@ -64,6 +65,7 @@ static GList *get_custom_list_from_name(const gchar * label);
 static void add_ranges(void);
 static void add_modlist(void);
 
+int drag_module_type;
 
 static GList *list_of_finds;
 /******************************************************************************
@@ -656,6 +658,61 @@ void main_delete_module(GtkTreeView *treeview)
 }
 
 
+void main_add_mod_to_list(GtkWidget * tree_widget, gchar * mod_name)
+{
+	GtkTreeModel *model_mods;
+	GtkTreeModel *model_modules_lists;
+	GtkTreeIter iter;
+	GtkTreeIter selected_modules_lists;
+	GtkListStore *list_store;
+	GtkListStore *store_modules_lists;
+	gchar *mod_description = NULL;
+	gchar *mod_list = NULL;
+	GList *mods = NULL;
+	GtkTreeSelection *selection_modules_lists;
+	
+	model_modules_lists =
+	    gtk_tree_view_get_model(GTK_TREE_VIEW(search1.module_lists));
+	store_modules_lists = GTK_LIST_STORE(model_modules_lists);
+
+	selection_modules_lists = gtk_tree_view_get_selection
+	    (GTK_TREE_VIEW(search1.module_lists));
+	    
+	model_mods =
+	    gtk_tree_view_get_model(GTK_TREE_VIEW(tree_widget));
+	list_store = GTK_LIST_STORE(model_mods);
+	mod_description = backendSearch->module_description(mod_name);
+
+			gtk_list_store_append(list_store, &iter);
+			gtk_list_store_set(list_store, &iter,
+					   0, mod_description,
+					   1, mod_name, -1);
+			mods = get_current_list();
+			mod_list = get_modlist_string(mods);
+
+			if (mod_list) {
+				gtk_tree_selection_get_selected
+	   			       (selection_modules_lists, NULL, 
+					          &selected_modules_lists);
+				
+				gtk_list_store_set(store_modules_lists,
+						   &selected_modules_lists,
+						   1, mod_list, -1);
+				g_free(mod_list);
+			}
+			++search1.module_count;
+}
+
+void main_drag_drop_display_in_main(const char * uri)
+{
+
+
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets.notebook_comm_book),
+						      1);
+
+}
+
+
 /******************************************************************************
  * Name
  *   mod_selection_changed
@@ -812,7 +869,8 @@ void main_selection_finds_list_changed(GtkTreeSelection *
 void main_finds_verselist_selection_changed(GtkTreeSelection * selection, 
                                                                       gpointer data)
 {
-	gchar *text, *text_str, *buf, *module;
+	gchar *text, *text_str, *buf, *module, *key;
+	gchar **work_buf = NULL; 
 	gint i, textlen;
 	GtkTreeModel *model;
 	GtkTreeIter selected;
@@ -836,20 +894,28 @@ void main_finds_verselist_selection_changed(GtkTreeSelection * selection,
 	buf = strchr(text,':');
 	++buf;
 	++buf;
-	text_str = backendSearch->get_render_text(module,buf);
+	work_buf = g_strsplit(buf," ",3);
+	key = g_strdup_printf("%s %s",work_buf[0],work_buf[1]);
+					     
+	if(verse_selected) g_free(verse_selected);
+	drag_module_type = backendSearch->module_type(module);
+	if(drag_module_type == BOOK_TYPE)
+		verse_selected = g_strdup_printf("sword://%s/%lu",module,
+		       		backendSearch->get_treekey_offset_from_key(
+						module, key));
+	else 
+		verse_selected = g_strdup_printf("sword://%s/%s",module,key);
+	text_str = backendSearch->get_render_text(module,key);
 	
 	gtk_html_load_from_string(GTK_HTML(search1.preview_html),text_str,strlen(text_str));
-	
-/*	gtk_text_buffer_get_start_iter(tbuf, &startiter);
-	gtk_text_buffer_get_end_iter(tbuf, &enditer);
-	gtk_text_buffer_delete(tbuf, &startiter, &enditer);
-	
-	gtk_text_buffer_get_end_iter(tbuf, &iter);
-	gtk_text_buffer_insert_with_tags(tbuf, &iter,text_str,strlen(text_str),NULL);
-*/	
+#ifdef DEBUG
+	g_message("main_finds_verselist_selection_changed: %s %s",work_buf[0],work_buf[1]);
+#endif
 	if(text) g_free(text);	
 	g_free(module);
+	g_free(key);
 	g_free(text_str);
+	g_strfreev(work_buf);
 }
 
 
@@ -1314,6 +1380,7 @@ void main_do_dialog_search(void)
 	GtkListStore *list_store2;
 	GtkTreeIter iter2;
 	gint x = 0;
+	gint mod_type;
 	
 	_clear_find_lists();
 	model =
@@ -1354,6 +1421,11 @@ void main_do_dialog_search(void)
 	search_params = GTK_TOGGLE_BUTTON
 	    (search1.cb_case_sensitive)->active ? 0 : REG_ICASE;
 
+	// For attribute-based searches, e.g. "Word//Lemma/G140",
+	// we must constrain the match to whole words.  Otherwise,
+	// we will inadvertently return e.g. 140 plus 1401 and 1404.
+	if (search_type == -3)
+		search_params |= SEARCHFLAG_MATCHWHOLEENTRY;
 
 	if (GTK_TOGGLE_BUTTON(search1.rb_custom_list)->active) {
 		const gchar *name;
@@ -1391,10 +1463,14 @@ void main_do_dialog_search(void)
 		tmp_list = NULL;
 		
 		while ((key_buf = backendSearch->get_next_listkey()) != NULL) {
-				g_string_printf(str, "%s: %s %s", module,  key_buf, backendSearch->get_strip_text(module, key_buf));
-									
-				tmp_list = g_list_append(tmp_list, (char*) g_strdup(str->str));
-				g_free((char*)key_buf);	
+			/* test for mod type */
+			mod_type = backendSearch->module_type(module);	
+			if(mod_type == TEXT_TYPE)			
+				g_string_printf(str, "%s: %s  %s", module,  key_buf, backendSearch->get_strip_text(module, key_buf));
+			else			
+				g_string_printf(str, "%s: %s", module,  key_buf);				
+			tmp_list = g_list_append(tmp_list, (char*) g_strdup(str->str));
+			g_free((char*)key_buf);	
 		}
 		list_of_finds = g_list_append(list_of_finds, (GList*)tmp_list);
 		// add number of hits in each module to finds listview
@@ -1443,10 +1519,12 @@ void main_open_search_dialog(void)
 		GtkTreeIter iter;
 		
 		backendSearch = new BackEnd();
-
+		
 		/* create and show search dialog */
 		gui_create_search_dialog();
-
+		backendSearch->init_SWORD(2);
+		
+		
 		/* initiate module count to 0 */
 		search1.module_count = 0;
 
