@@ -33,6 +33,7 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <string.h>
+#include <errno.h>
 
 #include "gui/bookmarks.h"
 #include "gui/setup_druid.h"
@@ -47,8 +48,9 @@
 /******************************************************************************
  * defines
  */
-#define GS_DIR ".gnomesword-2.0"
+#define GS_DIR ".gnomesword"
 
+#define GS_NET_PERMISSION	"Welcome to GnomeSword.\n\nThere are no Bible modules installed. In order to initialize, GnomeSword needs you to install at least one Bible.\n\nWith your permission, GnomeSword will invoke the Module Manager so that you may install from Crosswire:\n1. Configure remote install.\n2. Connect.\n3. Select a Bible text of your language preference.\n4. Click `install'.\nClose the Module Manager when you are done.\n\nWarning: If you live in a persecuted country, use with care.\n\nMay GnomeSword invoke the Module Manager so that you may install a Bible?"
 
 /******************************************************************************
  * globals
@@ -99,23 +101,33 @@ int settings_init(int new_configs, int new_bookmarks)
 		exit(0);
 	}
 
-	/* set gSwordDir to $home + .gnomesword-2.0 */
+	/* set gSwordDir to $home + .gnomesword */
 	settings.gSwordDir = g_new(char, strlen(settings.homedir) +
 				   strlen(GS_DIR) + 2);
 	sprintf(settings.gSwordDir, "%s/%s", settings.homedir, GS_DIR);
 
-	/* if gSwordDir does not exist create it */
+	/* if gSwordDir does not exist, create it. */
 	if (access(settings.gSwordDir, F_OK) == -1) {
-		gs_old = g_strdup_printf("%s/.gnomesword-1.0",settings.homedir);		
+		gs_old = g_strdup_printf("%s/.gnomesword-2.0", settings.homedir);
 		if (access(gs_old, F_OK) == 0) {
-			if(rename(gs_old,settings.gSwordDir) != 0) {
-				printf("can not rename  .gnomesword-1.0");
+			if (rename(gs_old, settings.gSwordDir) == 0)
+				gui_generic_warning("GnomeSword has renamed .gnomesword-2.0 to .gnomesword");
+			else {
+				char msg[300];
+				sprintf(msg, "GnomeSword can not rename  .gnomesword-2.0 to .gnomesword:\n%s\n\nGnomeSword cannot continue.",
+					strerror(errno));
+				gui_generic_warning(msg);
+				/* necessarily giving up. */
+				gtk_exit(1);
 			}
 		} else if ((mkdir(settings.gSwordDir, S_IRWXU)) != 0) {
-			printf("can not create  .gnomesword-2.0");
+			char msg[300];
+			sprintf(msg, "GnomeSword can not create  .gnomesword:\n%s\n\nGnomeSword cannot continue.",
+				strerror(errno));
+			gui_generic_warning(msg);
 			/* if we can not create gSwordDir exit */
 			gtk_exit(1);
-		} 
+		}
 		g_free(gs_old);
 	}
 
@@ -125,8 +137,7 @@ int settings_init(int new_configs, int new_bookmarks)
 		gui_save_tabs(NULL);
 	g_free(tabs);
 */
-	
-	
+
 	/* if .sword does not exist create it */
 	sword_dir = g_strdup_printf("%s/%s", settings.homedir, ".sword");
 	if (access(sword_dir, F_OK) == -1) {
@@ -162,23 +173,33 @@ int settings_init(int new_configs, int new_bookmarks)
 		"settings.xml");
 	
 	/* if settings.xml does not exist create it */
-	if (access(settings.fnconfigure, F_OK) == -1) {
+	if ((access(settings.fnconfigure, F_OK) == -1) || new_configs) {
 		/* must be first run */
 #ifdef DEBUG 
 		g_print("\nFirst Run: need to create settings!\n");
 #endif
 		settings.first_run = TRUE;
 
-		sword_dir = g_strdup_printf("%s/%s", settings.homedir, ".sword/modules/texts");
-		if (access(sword_dir, F_OK) == -1) {
-			gui_generic_warning
-			    ("Must invoke install manager for 1 Bible text.\nThis may take a minute or two.");
-			backend_init_module_mgr_config();
-			system("cd ; cd .sword ; installmgr -r crosswire ; installmgr -ri crosswire ESV ; rm -f dirlist");
-			gui_generic_warning
-			    ("Bible text installation complete");
+		main_init_lists();
+		if (settings.havebible == 0) {
+			if (gui_yes_no_dialog(GS_NET_PERMISSION)) {
+				main_shutdown_list();
+				gui_open_mod_mgr_initial_run();
+				main_init_lists();
+				if (settings.havebible == 0) {
+					gui_generic_warning
+					    ("There are still no Bibles installed.\nEvidently, you declined to install any.\n\nWithout any Bible modules to display, GnomeSword cannot proceed, and will now exit.");
+					exit(1);
+				} else
+					gui_generic_warning
+					    ("Bible module installation complete.");
+			} else {
+				gui_generic_warning
+				    ("Without any Bible modules to display, GnomeSword cannot proceed, and will now exit.");
+				exit(1);
+			}
 		}
-		g_free(sword_dir);
+		main_shutdown_list();
 
 		main_init_lists();
 		xml_create_settings_file(settings.fnconfigure);
@@ -341,7 +362,7 @@ void load_settings_structure(void)
 	if(xml_get_value("keys", "offset"))
 		settings.book_offset = atol(xml_get_value("keys", "offset"));
 	else {
-		xml_add_new_item_to_section("keys", "offset", "0");
+		xml_add_new_item_to_section("keys", "offset", "");
 		settings.book_offset = 0;
 	}
 
@@ -450,6 +471,7 @@ void load_settings_structure(void)
 		settings.showpreview = atol(xml_get_value("misc", "showpreview"));
 	else {
 		xml_add_new_item_to_section("misc", "showpreview", "1");
+		settings.showpreview = 1;
 	}
 
 //#ifdef USE_GTKHTML30	
@@ -462,22 +484,27 @@ void load_settings_structure(void)
 	    atoi(xml_get_value("misc", "dailydevotional"));
 	settings.versestyle = atoi(xml_get_value("misc", "versestyle"));
 
-	buf = xml_get_value("misc", "pinnedtabs");
-	if (buf)
+	if (buf = xml_get_value("misc", "pinnedtabs"))
 		settings.pinnedtabs = atoi(buf);
 	else {
 		xml_add_new_item_to_section("misc", "pinnedtabs", "0");
 		settings.pinnedtabs = 0;
 	}
 
-	buf = xml_get_value("misc", "readaloud");
-	if (buf)
+	if (buf = xml_get_value("misc", "readaloud"))
 		settings.readaloud = atoi(buf);
 	else {
 		xml_add_new_item_to_section("misc", "readaloud", "0");
 		settings.readaloud = 0;
 	}
 
+	if (buf = xml_get_value("misc", "showversenum"))
+		settings.showversenum = atoi(buf);
+	else {
+		xml_add_new_item_to_section("misc", "showversenum", "1");
+		settings.showversenum = 1;
+	}
+
 	settings.usedefault = atoi(xml_get_value("misc", "usedefault"));
 	
 		
@@ -487,6 +514,20 @@ void load_settings_structure(void)
 		xml_add_new_item_to_section("misc","setup_canceled","0");
 		settings.setup_canceled = atoi(xml_get_value("misc", "setup_canceled"));
 	}
+	
+	if (buf = xml_get_value("misc", "chapter-scroll")) {
+		settings.chapter_scroll = atoi(buf);
+	} else {
+		xml_add_new_item_to_section("misc","chapter-scroll","0");
+		settings.chapter_scroll = 0;
+	}
+
+	if (buf = xml_get_value("misc", "imageresize")) {
+		settings.imageresize = atoi(buf);
+	} else {
+		xml_add_new_item_to_section("misc","imageresize","0");
+		settings.imageresize = 0;
+	}
 
 /*	settings.use_studypad =
 	    atoi(xml_get_value("editor", "UseStudyPad"));
@@ -494,8 +535,9 @@ void load_settings_structure(void)
 	    atoi(xml_get_value("editor", "UseStudypadDialog"));
 	settings.use_percomm_dialog =
 	    atoi(xml_get_value("editor", "UsePercommDialog"));*/
-	if(xml_get_value("editor", "spell_language"))
-	     settings.spell_language = xml_get_value("editor","spell_language");
+
+	if (xml_get_value("editor", "spell_language"))
+		settings.spell_language = xml_get_value("editor","spell_language");
 	else {
 		xml_add_new_item_to_section("editor","spell_language","unknown");
 		settings.spell_language = "unknown";
@@ -505,17 +547,30 @@ void load_settings_structure(void)
 	settings.studypadfilename =
 	    xml_get_value("studypad", "lastfile");
 	settings.studypaddir = xml_get_value("studypad", "directory");
-
-	buf = xml_get_value("shortcutbar", "shortcutbar");
-	if(buf)
+/*
+	if (buf = xml_get_value("shortcutbar", "shortcutbar"))
 		settings.showshortcutbar = atoi(buf);
 	
-	buf = xml_get_value("shortcutbar", "docked");
-	if(buf)
+	if (buf = xml_get_value("shortcutbar", "docked"))
 		settings.docked =  atoi(buf);
 	
+*/		
+	if (xml_get_value("misc", "show_sidebar")) {
+		buf = xml_get_value("misc", "show_sidebar");
+		settings.showshortcutbar = atoi(buf);
+	} else {
+		xml_add_new_item_to_section("misc","show_sidebar","1");
+		settings.showshortcutbar = 1;
+	}		
+	if (xml_get_value("misc", "sidebar_docked")) {
+		buf = xml_get_value("misc", "sidebar_docked");
+		settings.docked = atoi(buf);
+	} else {
+		xml_add_new_item_to_section("misc","sidebar_docked","1");
+		settings.docked = 1;
+	}
 	
-	if(xml_get_value("tabs", "browsing")) {
+	if (xml_get_value("tabs", "browsing")) {
 		buf = xml_get_value("tabs", "browsing");
 		settings.browsing =  atoi(buf);
 	} else {
