@@ -623,6 +623,12 @@ void main_mod_treeview_button_one(GtkTreeModel * model,
 					      (widgets.
 					       notebook_bible_parallel),
 					      0);
+		if(strcmp(settings.MainWindowModule, mod)) {
+			xml_set_value("GnomeSword", "modules", "bible",
+						mod);
+			settings.MainWindowModule = xml_get_value(
+					"modules", "bible");
+		}	
 		if (!gtk_tree_model_iter_has_child
 		    (GTK_TREE_MODEL(model), &selected)
 		    && !key)
