@@ -85,6 +85,70 @@ extern GtkWidget *cbe_freeform_lookup;
 extern gboolean shift_key_presed;
 
 gboolean style_display = TRUE;
+char *sword_locale = NULL;
+
+
+/******************************************************************************
+ * Name
+ *   main_book_heading
+ *
+ * Synopsis
+ *   #include "main/sword.h"
+ *
+ *   void main_book_heading(char * mod_name)
+ *
+ * Description
+ *   
+ *
+ * Return value
+ *   void
+ */
+
+void main_book_heading(char * mod_name)
+{	
+	VerseKey *vkey;	
+	SWMgr *mgr = backend->get_display_mgr();
+	
+	backend->display_mod = mgr->Modules[mod_name];
+	vkey = (VerseKey*)(SWKey*)(*backend->display_mod);	
+	vkey->Headings(1);
+	vkey->AutoNormalize(0);
+	vkey->Verse(0);
+	vkey->Chapter(0);
+	backend->display_mod->Display();
+}
+
+
+/******************************************************************************
+ * Name
+ *   main_chapter_heading
+ *
+ * Synopsis
+ *   #include "main/module_dialogs.h"
+ *
+ *   void main_chapter_heading(char * mod_name)
+ *
+ * Description
+ *   
+ *
+ * Return value
+ *   void
+ */
+
+void main_chapter_heading(char * mod_name)
+{	
+	VerseKey *vkey;	
+	SWMgr *mgr = backend->get_display_mgr();
+	
+	backend->display_mod = mgr->Modules[mod_name];
+	backend->display_mod->setKey(settings.currentverse);
+	vkey = (VerseKey*)(SWKey*)(*backend->display_mod);	
+	vkey->Headings(1);
+	vkey->AutoNormalize(0);
+	vkey->Verse(0);
+	backend->display_mod->Display();
+}
+
 
 /******************************************************************************
  * Name
@@ -108,6 +172,17 @@ void main_save_note(	const gchar * module_name,
 			const gchar * key_str, 
 			const gchar * note_str )
 {
+	// Massage encoded spaces ("%20") back to real spaces.
+	// This is a sick. unreliable hack that should be removed
+	// after the underlying problem is fixed in Sword.
+	gchar *rework;
+	for (rework = strstr(note_str, "%20");
+	     rework;
+	     rework = strstr(rework+1, "%20")) {
+		*rework = ' ';
+		(void) strcpy(rework+1, rework+3);
+	}
+
 #ifdef USE_GTKHTML38
 	backend->set_module_key(module_name, key_str);
 #ifdef DEBUG
@@ -118,6 +193,9 @@ void main_save_note(	const gchar * module_name,
 #endif
 	backend->save_entry(note_str);
 #endif
+	if((!strcmp(settings.CommWindowModule,module_name)) &&  
+				(!strcmp(settings.currentverse, key_str)))
+		main_display_commentary(module_name, key_str);
 }
 
 /******************************************************************************
@@ -136,8 +214,7 @@ void main_save_note(	const gchar * module_name,
  *   void
  */
 
-void main_delete_note(	const gchar * module_name, 
-								const gchar * key_str)
+void main_delete_note(	const gchar * module_name, const gchar * key_str)
 {
 #ifdef USE_GTKHTML38
 	backend->set_module_key(module_name, key_str);
@@ -148,6 +225,9 @@ void main_delete_note(	const gchar * module_name,
 #endif
 	backend->delete_entry();
 #endif	
+	if((!strcmp(settings.CommWindowModule,module_name)) &&  
+				(!strcmp(settings.currentverse, key_str)))
+		main_display_commentary(module_name, key_str);
 }
 
 	
@@ -439,12 +519,12 @@ char *main_get_path_to_mods(void)
 
 void main_init_backend(void)
 {	
-	char *sword_locale = NULL;
 	char *sys_locale = NULL;
 	const char *lang = getenv("LANG");
 	SWMgr mgr;
 	
 	if (!lang) lang="C";
+	
 	backend = new BackEnd();
 	backend->init_SWORD(0);
 	sword_locale = backend->set_sword_locale(lang);
@@ -461,7 +541,7 @@ void main_init_backend(void)
 	sys_locale = strdup(lang);
 	settings.spell_language = strdup(sys_locale);	
 	main_init_lists();
-	free((char*)sword_locale);
+//	free((char*)sword_locale);
 	free(sys_locale);	
 }
 
@@ -484,7 +564,11 @@ void main_init_backend(void)
 
 void main_shutdown_backend(void)
 {
-	delete backend; 
+	free((char*)sword_locale);
+	if(backend) 
+	        delete backend; 
+	backend = NULL;
+		
 #ifdef DEBUG	
 	g_print("%s\n", _("SWORD is shutdown"));
 #endif
@@ -616,7 +700,8 @@ void main_dictionary_entry_changed(char * mod_name)
 	gchar *key = NULL;
 	gchar *key2 = NULL;
 	
-	
+	if(!mod_name) 
+		return;
 	if(strcmp(settings.DictWindowModule,mod_name)) {
 		xml_set_value("GnomeSword", "modules", "dict",
 					mod_name);
@@ -647,8 +732,24 @@ void main_dictionary_entry_changed(char * mod_name)
 
 static void dict_key_list_select(GtkMenuItem * menuitem, gpointer user_data)
 {
+	gchar *buf;                                       
+	gsize bytes_read;
+	gsize bytes_written;
+	GError **error = NULL;	
+	
+	buf = g_convert((char*)(gchar*) user_data,
+                             -1,
+                             UTF_8,
+                             OLD_CODESET,
+                             &bytes_read,
+                             &bytes_written,
+                             error);
+#ifdef DEBUG
+	g_message("\nuser_data: %s\nbuf: %s",(gchar*) user_data,buf);
+#endif
 	gtk_entry_set_text(GTK_ENTRY(widgets.entry_dict), (gchar*) user_data);
 	gtk_widget_activate(widgets.entry_dict);
+	g_free(buf);
 }
 
 /******************************************************************************
@@ -680,15 +781,19 @@ GtkWidget *main_dictionary_drop_down_new(char * mod_name, char * old_key)
 	
 	menu = gtk_menu_new();
 	
+	if(!settings.havedict || !mod_name)
+		return NULL;
 	if(strcmp(settings.DictWindowModule,mod_name)) {
 		xml_set_value("GnomeSword", "modules", "dict",
 					mod_name);
 		settings.DictWindowModule = xml_get_value(
 					"modules", "dict");
 	}	
-	
 	key = g_strdup((gchar*)gtk_entry_get_text(GTK_ENTRY(widgets.entry_dict)));
 	
+#ifdef DEBUG
+	g_message("\nold_key: %s\nkey: %s",old_key,key);
+#endif	
 	key2 = g_utf8_strup(key,strlen(key));
 	
 	backend->set_module_key(mod_name, key2);
@@ -710,14 +815,14 @@ GtkWidget *main_dictionary_drop_down_new(char * mod_name, char * old_key)
 	new_key = g_strdup((char*)backend->display_mod->KeyText());
 	
 	for (i = 0; i < (count / 2)+1; i++) {
-		free(new_key);
+		//free(new_key);
 		(*backend->display_mod)--;
 		/*new_key = g_locale_to_utf8((char*)backend->display_mod->KeyText(),
                                              -1,
                                              NULL,
                                              &bytes_written,
                                              NULL);*/
-		new_key = g_strdup((char*)backend->display_mod->KeyText());
+		//new_key = g_strdup((char*)backend->display_mod->KeyText());
 	}
 
 	for (i = 0; i < count; i++) {
@@ -768,6 +873,10 @@ GtkWidget *main_dictionary_drop_down_new(char * mod_name, char * old_key)
 void main_dictionary_button_clicked(gint direction)
 {	
 	gchar *key = NULL;
+	
+	if(!settings.havedict || !settings.DictWindowModule)
+		return;
+		
 	backend->set_module_key(settings.DictWindowModule, 
 				settings.dictkey);
 	if(direction == 0)
@@ -782,6 +891,7 @@ void main_dictionary_button_clicked(gint direction)
 
 void main_display_book(const char * mod_name, char * key)
 {
+	gboolean use_offset = FALSE;
 	if(!settings.havebook || !mod_name)
 		return;
 	if(!backend->is_module(mod_name))
@@ -789,17 +899,29 @@ void main_display_book(const char * mod_name, char * key)
 	if(!settings.book_mod)
 		settings.book_mod = (char*)mod_name;
 	
-	settings.whichwindow = BOOK_WINDOW;
 	
-	xml_set_value("GnomeSword", "keys", "offset", key);
-	settings.book_offset = atol(xml_get_value( "keys", "offset"));
+	settings.whichwindow = BOOK_WINDOW;
+	if(key == NULL) key = "0";
+	if(isalpha(key[0])) {
+		xml_set_value("GnomeSword", "keys", "book", key);
+		settings.book_key = xml_get_value( "keys", "book");
+		use_offset = FALSE;
+	} else {
+		xml_set_value("GnomeSword", "keys", "offset", key);
+		settings.book_offset = atol(xml_get_value( "keys", "offset"));
+		use_offset = TRUE;
+	}
 	
 	if(strcmp(settings.book_mod,mod_name)) {
 		xml_set_value("GnomeSword", "modules", "book", mod_name);
 		settings.book_mod = xml_get_value( "modules", "book");
 	}
-	backend->set_module(mod_name);
-	backend->set_treekey(settings.book_offset);
+	if(use_offset) {
+		backend->set_module(mod_name);	
+		backend->set_treekey(settings.book_offset);
+	} else {
+		backend->set_module_key(mod_name, key);
+	}
 	backend->display_mod->Display();
 	
 	if(settings.browsing)
@@ -828,7 +950,7 @@ void main_display_commentary(const char * mod_name, const char * key)
 	
 	settings.comm_showing = TRUE;
 	settings.whichwindow = COMMENTARY_WINDOW;
-	
+						
 	if(strcmp(settings.CommWindowModule,mod_name)) {
 		xml_set_value("GnomeSword", "modules", "comm", mod_name);
 		settings.CommWindowModule = xml_get_value( "modules", "comm");
@@ -930,6 +1052,11 @@ void main_display_bible(const char * mod_name, const char * key)
 	gchar *style = NULL;
 	gchar *val_key = NULL;
 	
+	extern guint scroll_adj_signal;
+	extern GtkAdjustment* adjustment;
+	
+	/* keeps us out of a crash causing loop */
+	g_signal_handler_block(adjustment, scroll_adj_signal);
 	
 	if(!mod_name)
 		mod_name = xml_get_value("modules", "bible");	
@@ -959,7 +1086,7 @@ void main_display_bible(const char * mod_name, const char * key)
 		if(navbar_main.module_name) 
 			g_free(navbar_main.module_name);
 		navbar_main.module_name = g_strdup(settings.MainWindowModule);
-		if(navbar_main.key) 
+		if(navbar_main.key)
 			g_free(navbar_main.key);
 		navbar_main.key = g_strdup(settings.currentverse);
 		main_navbar_fill_book_combo(navbar_main);
@@ -1016,6 +1143,7 @@ void main_display_bible(const char * mod_name, const char * key)
 		main_update_parallel_page();
 	else
 		gui_keep_parallel_dialog_in_sync();
+	g_signal_handler_unblock(adjustment, scroll_adj_signal);
 }
 
 
