@@ -43,7 +43,6 @@
 #include "gui/html.h"
 #include "gui/gnomesword.h"
 #include "gui/widgets.h"
-#include "gui/hints.h"
 #include "gui/utilities.h"
 #include "gui/sidebar.h"
 #include "gui/dialog.h"
@@ -339,7 +338,9 @@ static gint show_strongs(const gchar * type, const gchar * value,
 	guint i;	
 	
 	val = g_strdup(value);
+#ifdef DEBUG 
 	g_message("buf len = %d",strlen(buf));
+#endif
 	/*if((val1 = strchar(val,'|')) != NULL)	{
 		val1 = (val1) ? (val1 + 1) : val;
 		
@@ -457,7 +458,9 @@ static gint show_strongs_morph(const gchar * type, const gchar * value,
 	if(morph_mod)  {		
 		if(strchr(buf,'|')) {
 			gint morphlen = strlen(morph);
-			g_message("buf = %s", buf);	
+#ifdef DEBUG
+			g_message("buf = %s", buf);
+#endif
 			for (i = 0; i < morphlen; i++) {
 				if(morph[i] == '|') {
 					val[i] = '\0';
@@ -468,8 +471,10 @@ static gint show_strongs_morph(const gchar * type, const gchar * value,
 			val2 = strchr(buf,'|');
 			++val2;
 			
+#ifdef DEBUG
 			g_message("val = %s", val);
 			g_message("val2 = %s", val2);
+#endif
 			morph_buf = g_strdup_printf("%s<br />%s<br /><br />%s<br />%s",
 					val,
 					main_get_rendered_text(morph_mod, (gchar*)val),
@@ -789,7 +794,10 @@ static gint sword_uri(const gchar * url, gboolean clicked)
 	}
 	
 	work_buf = g_strsplit (url,"/",4);
-	//g_message("work_buf :%s, %s",work_buf[2],work_buf[KEY]);
+	//if(work_buf[KEY][0] == '/' ) ++work_buf[KEY];
+#ifdef DEBUG
+	g_message("work_buf :%s, %s",work_buf[2],work_buf[KEY]);
+#endif
 	if(!work_buf[2] && !work_buf[KEY]) {
 		alert_url_not_found(url);
 		g_strfreev(work_buf);
@@ -800,14 +808,14 @@ static gint sword_uri(const gchar * url, gboolean clicked)
 	} else
 		tmpkey = work_buf[KEY];
 	
-	mykey = g_convert(tmpkey,
+/*	mykey = g_convert(tmpkey,
                              -1,
                              OLD_CODESET,
                              UTF_8,
                              &bytes_read,
                              &bytes_written,
                              error);
-	
+*/	
 	verse_count = 1; //backend->is_Bible_key(mykey, settings.currentverse);
 	/*if(!work_buf[3] && !verse_count){
 		alert_url_not_found(url);
@@ -828,6 +836,7 @@ static gint sword_uri(const gchar * url, gboolean clicked)
 				if(key) g_free((gchar*)key);
 			break;				
 			case COMMENTARY_TYPE:	
+				//settings.comm_showing = TRUE;
 				key = main_update_nav_controls(tmpkey);
 				main_display_commentary(work_buf[MODULE],key);
 				main_display_bible(NULL, key);
