@@ -500,6 +500,13 @@ int xml_create_settings_file(char *path)
 
 	section_node = xmlNewChild(root_node, NULL,
 				   (const xmlChar *) "modlists", NULL);
+	cur_node = xmlNewChild(section_node,
+			       NULL, (const xmlChar *) "modlist", NULL);
+	xml_attr = xmlNewProp(cur_node,
+			      (const xmlChar *) "label",
+			      (const xmlChar *) "Sample Module List");
+	xml_attr =
+	    xmlNewProp(cur_node, (const xmlChar *) "list", (const xmlChar *) "Select the modules you want");
 
 
 	section_node = xmlNewChild(root_node, NULL,
@@ -578,6 +585,7 @@ int xml_create_settings_file(char *path)
 	xmlNewTextChild(section_node, NULL, (const xmlChar *)"showtexts", (const xmlChar *)"1");
 	xmlNewTextChild(section_node, NULL, (const xmlChar *)"versestyle", (const xmlChar *)"1");
 	xmlNewTextChild(section_node, NULL, (const xmlChar *)"pinnedtabs", (const xmlChar *)"0");
+	xmlNewTextChild(section_node, NULL, (const xmlChar *)"showversenum", (const xmlChar *)"1");
 	xmlNewTextChild(section_node, NULL, (const xmlChar *)"readaloud", (const xmlChar *)"0");
 	xmlNewTextChild(section_node, NULL, (const xmlChar *)"setup_canceled",(const xmlChar *)"0");
 
